pub struct Opts {Show 19 fields
pub command: Option<Command>,
pub initialize: bool,
pub rebuild_indexes: bool,
pub development: bool,
pub domain: String,
pub port: u32,
pub port_https: u32,
pub ip: IpAddr,
pub https: bool,
pub https_dns: bool,
pub email: Option<String>,
pub script: String,
pub config_dir: Option<PathBuf>,
pub data_dir: Option<PathBuf>,
pub public_mode: bool,
pub server_url: Option<String>,
pub log_level: LogLevel,
pub trace: Tracing,
pub slow_mode: bool,
}Expand description
Store and share Atomic Data! Visit https://atomicdata.dev for more info. Pass no subcommands to launch the server. The .env of your current directory will be read.
Fields
command: Option<Command>The subcommand being run
initialize: boolRecreates the /setup Invite for creating a new Root User. Also re-runs various populate commands, and re-builds the index
rebuild_indexes: boolRe-builds the indexes. Parses all the resources. Do this when updating requires it, or if you have issues with Collections / Queries / Search.
development: boolUse staging environments for services like LetsEncrypt
domain: StringThe origin domain where the app is hosted, without the port and schema values.
port: u32The port where the HTTP app is available. Set to 80 if you want this to be available on the network.
port_https: u32The port where the HTTPS app is available. Set to 443 if you want this to be available on the network.
ip: IpAddrThe IP address of the server. Set to :: if you want this to be available to other devices on your network.
https: boolUse HTTPS instead of HTTP. Will get certificates from LetsEncrypt fully automated.
https_dns: boolInitializes DNS-01 challenge for LetsEncrypt. Use this if you want to use subdomains.
email: Option<String>The contact mail address for Let’s Encrypt HTTPS setup
script: StringCustom JS script to include in the body of the HTML template
config_dir: Option<PathBuf>Path for atomic data config directory. Defaults to “~/.config/atomic/”“
data_dir: Option<PathBuf>Path for atomic data store folder. Contains your Store, uploaded files and more. Default value depends on your OS.
public_mode: boolCAUTION: Skip authentication checks, making all data publicly readable. Improves performance.
server_url: Option<String>The full URL of the server. It should resolve to the home page. Set this if you use an external server or tunnel, instead of directly exposing atomic-server. If you leave this out, it will be generated from domain, port and http / https.
log_level: LogLevelHow much logs you want. Also influences what is sent to your trace service, if you’ve set one (e.g. OpenTelemetry)
trace: TracingHow you want to trace what’s going on with the server. Useful for monitoring performance and errors in production.
Combine with log_level to get more or less data (trace is the most verbose)
slow_mode: boolIntroduces random delays in the server, to simulate a slow connection. Useful for testing.